Checkbox-ng
===========

:term:`Checkbox-ng` is a hardware testing tool useful for certifying laptops,
desktops, servers and IOT devices with Ubuntu.

Installation
============

$ sudo add-apt-repository ppa:checkbox-dev/ppa
$ sudo apt-get update
$ sudo apt-get install checkbox-ng

Documentation
=============

* `Using Checkbox <http://checkbox.readthedocs.io/en/latest/>`_

Known Issues
============

https://bugs.launchpad.net/checkbox-project
